--       _________ __                 __
--      /   _____//  |_____________ _/  |______     ____  __ __  ______
--      \_____  \\   __\_  __ \__  \\   __\__  \   / ___\|  |  \/  ___/
--      /        \|  |  |  | \// __ \|  |  / __ \_/ /_/  >  |  /\___ \
--     /_______  /|__|  |__|  (____  /__| (____  /\___  /|____//____  >
--             \/                  \/          \//_____/            \/
--  ______________________                           ______________________
--                        T H E   W A R   B E G I N S
--         Stratagus - A free fantasy real time strategy game engine
--
--      scepter_of_fire_events.lua - Defines events for the Scepter of Fire campaign.
--
--      (c) Copyright 2010-2014 by Kyran Jackson
--
--      This program is free software; you can redistribute it and/or modify
--      it under the terms of the GNU General Public License as published by
--      the Free Software Foundation; either version 2 of the License, or
--      (at your option) any later version.
--
--      This program is distributed in the hope that it will be useful,
--      but WITHOUT ANY WARRANTY; without even the implied warranty of
--      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--      GNU General Public License for more details.
--
--      You should have received a copy of the GNU General Public License
--      along with this program; if not, write to the Free Software
--      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
--

if (mapinfo.description == "Seawill Forest") then
	AddTrigger(
		function()
			if (GameCycle == 0) then
				return false
			end
			for i=0,14 do
				if ((GetPlayerData(i, "UnitTypesCount", "unit-hero-rugnur") + GetPlayerData(i, "UnitTypesCount", "unit-hero-rugnur-steelclad") + GetPlayerData(i, "UnitTypesCount", "unit-hero-rugnur-thane")) >= 1) then
					player = i
					return true
				end
			end
			return false
		end,
		function() 
			Event(
				"",
				"Rumors have been circulating that a band of rebel marauders have been harassing travellers in the Seawill Forest.\n\nYou have been tasked with visiting the Seawill lumbermill to see if there is any truth to these rumors.\n\nBe aware that we have no need for traitors. If these rumors are confirmed to be true, you are to bring a swift end to any renegades you encounter.",
				player,
				{"~!Continue"},
				{function(s)
					RemovePlayerObjective(player, "- Defeat your enemies")
					AddPlayerObjective(player, "- Bring Arthor Literios to your ally")
					AddPlayerObjective(player, "- Arthor Literios must not die")
				end}
			)

			AddTrigger(
				function()
					for i=0,14 do
						if (PlayerHasObjective(i, "- Bring Arthor Literios to your ally") and (GetNumUnitsAt(i, "unit-hero-rugnur", {0, 16}, {5, 22}) + GetNumUnitsAt(i, "unit-hero-rugnur-steelclad", {0, 16}, {5, 22}) + GetNumUnitsAt(i, "unit-hero-rugnur-thane", {0, 16}, {5, 22})) > 0) then
							player = i
							return true
						end
					end
					return false
				end,
				function() 
					RemovePlayerObjective(player, "- Bring Arthor Literios to your ally")
					RemovePlayerObjective(player, "- Arthor Literios must not die")
					if (player == GetThisPlayer()) then
						if (GetArrayIncludes(wyr.preferences.QuestsCompleted, "Seawill Forest") == false) then
							table.insert(wyr.preferences.QuestsCompleted, "Seawill Forest")
						end
						SavePreferences()
						NextMap = "mods/Aleona's Tales/maps/dunath-outpost.smp"
						ActionVictory()
					end
					return false
				end
			)

			AddTrigger(
				function()
					for i=0,14 do
						if (PlayerHasObjective(i, "- Arthor Literios must not die") and (GetNumUnitsAt(i, "unit-hero-rugnur", {0, 0}, {92, 92}) + GetNumUnitsAt(i, "unit-hero-rugnur-steelclad", {0, 0}, {92, 92}) + GetNumUnitsAt(i, "unit-hero-rugnur-thane", {0, 0}, {92, 92})) < 1) then
							player = i
							return true
						end
					end
					return false
				end,
				function() 
					if (player == GetThisPlayer()) then
						ActionDefeat()
					end
					return false
				end
			)

			return false
		end
	)
end

if (mapinfo.description == "Dunath Outpost") then
	AddTrigger(
		function()
			if (GameCycle == 0) then
				return false
			end
			for i=0,14 do
				if ((GetPlayerData(i, "UnitTypesCount", "unit-hero-rugnur") + GetPlayerData(i, "UnitTypesCount", "unit-hero-rugnur-steelclad") + GetPlayerData(i, "UnitTypesCount", "unit-hero-rugnur-thane")) >= 1) then
					player = i
					return true
				end
			end
			return false
		end,
		function() 
			Event(
				"",
				"Our decision to investigate the rumors of renegade minions has resulted in the discovery of a sizeable enemy present. Surprisingly, none of the local garrisons report any missing soldiers. This means that either the enemy forces have relocated here after defecting, or that they were never under our jurisdiction to begin with.\n\nThese revelations have lead to speculation that these rebels may in fact be coming through an as of yet undiscovered portal.",
				player,
				{"~!Continue"},
				{function(s)
					Event(
						"",
						"You are to take command of Dunath Outpost and see to its defenses. Your first task shall be to assign a worker to oversee the construction of a suitable barracks. Once it is complete you will be able to recruit five additional soldiers to help defend the position.",
						player,
						{"~!Continue"},
						{function(s)
							RemovePlayerObjective(player, "- Defeat your enemies")
							AddPlayerObjective(player, "- Build a War Hall")
							AddPlayerObjective(player, "- Train 5 Axefighters")
							AddPlayerObjective(player, "- Arthor Literios must not die")
						end}
					)
				end}
			)

			AddTrigger(
				function()
					for i=0,14 do
						if (PlayerHasObjective(i, "- Build a War Hall") and GetPlayerData(i, "UnitTypesCount", "unit-dwarven-axefighter") > 4 and GetPlayerData(i, "UnitTypesCount", "unit-dwarven-barracks") >= 1) then
							player = i
							return true
						end
					end
					return false
				end,
				function() 
					RemovePlayerObjective(player, "- Build a War Hall")
					RemovePlayerObjective(player, "- Train 5 Axefighters")
					RemovePlayerObjective(player, "- Arthor Literios must not die")
					if (player == GetThisPlayer()) then
						if (GetArrayIncludes(wyr.preferences.QuestsCompleted, "Dunath Outpost") == false) then
							table.insert(wyr.preferences.QuestsCompleted, "Dunath Outpost")
						end
						SavePreferences()
--						NextMap = "mods/Aleona's Tales/maps/dunath-outpost.smp"
						ActionVictory()
					end
					return false
				end
			)

			AddTrigger(
				function()
					for i=0,14 do
						if (PlayerHasObjective(i, "- Arthor Literios must not die") and (GetNumUnitsAt(i, "unit-hero-rugnur", {0, 0}, {92, 92}) + GetNumUnitsAt(i, "unit-hero-rugnur-steelclad", {0, 0}, {92, 92}) + GetNumUnitsAt(i, "unit-hero-rugnur-thane", {0, 0}, {92, 92})) < 1) then
							player = i
							return true
						end
					end
					return false
				end,
				function() 
					if (player == GetThisPlayer()) then
						ActionDefeat()
					end
					return false
				end
			)

			return false
		end
	)
end
